#########
test_data
#########

The test_data/ directory contains test Sphinx projects for testing under py.test.
They are intended to be linked into the `lsst-sqre/mock-doc <https://github.com/lsst-sqre/mock-doc>`_.
